@@ -32,14 +32,8 @@ vpn_agent_opts = [
         sample_default=['neutron_vpnaas.services.vpn.device_drivers.ipsec.'
                        'OpenSwanDriver, '
                        'neutron_vpnaas.services.vpn.device_drivers.'
-                       'cisco_ipsec.CiscoCsrIPsecDriver, '
-                       'neutron_vpnaas.services.vpn.device_drivers.'
-                       'vyatta_ipsec.VyattaIPSecDriver, '
-                       'neutron_vpnaas.services.vpn.device_drivers.'
                        'strongswan_ipsec.StrongSwanDriver, '
                        'neutron_vpnaas.services.vpn.device_drivers.'
-                       'fedora_strongswan_ipsec.FedoraStrongSwanDriver, '
-                       'neutron_vpnaas.services.vpn.device_drivers.'
                        'libreswan_ipsec.LibreSwanDriver'],
         help=_("The vpn device drivers Neutron will use")),
 ]
@@ -83,7 +77,7 @@ class VPNAgent(l3_extension.L3AgentExtension):
     def delete_router(self, context, data):
         """Handles router delete event"""
         for device_driver in self.device_drivers:
-            device_driver.destroy_router(data)
+            device_driver.destroy_router(data['id'])
 
     def ha_state_change(self, context, data):
         """Enable the vpn process when router transitioned to master.
@@ -94,8 +88,12 @@ class VPNAgent(l3_extension.L3AgentExtension):
         state = data['state']
         for device_driver in self.device_drivers:
             if router_id in device_driver.processes:
+                # NOTE(mnaser): We need to update the router object so it has
+                #               the new HA state so we can do status updates.
+                device_driver.routers[router_id].ha_state = state
+
                 process = device_driver.processes[router_id]
-                if state == 'master':
+                if state in ('master', 'primary'):
                     process.enable()
                 else:
                     process.disable()
