@@ -17,7 +17,6 @@ from unittest import mock
 
 import netaddr
 from neutron.agent.common import ovs_lib
-from neutron.agent.l3 import agent as neutron_l3_agent
 from neutron.agent.l3 import l3_agent_extensions_manager as ext_manager
 from neutron.agent.l3 import namespaces as n_namespaces
 from neutron.agent.l3 import router_info
@@ -32,7 +31,7 @@ from neutron.conf import common as common_config
 from neutron.services.provider_configuration import serviceprovider_opts
 from neutron.tests.common import l3_test_common
 from neutron.tests.common import net_helpers
-from neutron.tests.functional import base
+from neutron.tests.functional.agent.l3 import framework
 from neutron_lib import constants
 from neutron_lib.utils import net as n_utils
 from oslo_config import cfg
@@ -288,7 +287,7 @@ class SiteInfoWithHaRouter(SiteInfo):
         return info
 
 
-class TestIPSecBase(base.BaseSudoTestCase):
+class TestIPSecBase(framework.L3AgentTestFramework):
     NESTED_NAMESPACE_SEPARATOR = '@'
 
     def setUp(self):
@@ -314,9 +313,6 @@ class TestIPSecBase(base.BaseSudoTestCase):
         # Can reproduce the exception in the test only
         ip_lib.send_ip_addr_adv_notif = mock.Mock()
 
-        self.conf = self._configure_agent('agent1')
-        self.agent = neutron_l3_agent.L3NATAgentWithStateReport('agent1',
-                                                                self.conf)
         self.vpn_agent = vpn_agent.L3WithVPNaaS(self.conf)
         self.driver = self.vpn_agent.device_drivers[0]
         self.driver.agent_rpc.get_vpn_services_on_host = mock.Mock(
@@ -490,7 +486,7 @@ class TestIPSecBase(base.BaseSudoTestCase):
             site.backup_router = self.create_router(self.failover_agent,
                                                     backup_info)
             linux_utils.wait_until_true(
-                lambda: site.router.ha_state == 'master')
+                lambda: site.router.ha_state in ('master', 'primary'))
             linux_utils.wait_until_true(
                 lambda: site.backup_router.ha_state == 'backup')
 
@@ -558,7 +554,8 @@ class TestIPSecBase(base.BaseSudoTestCase):
         device_name = router1.get_ha_device_name()
         ha_device = ip_lib.IPDevice(device_name, router1.ns_name)
         ha_device.link.set_down()
-        linux_utils.wait_until_true(lambda: router2.ha_state == 'master')
+        linux_utils.wait_until_true(
+            lambda: router2.ha_state in ('master', 'primary'))
         linux_utils.wait_until_true(lambda: router1.ha_state == 'backup')
 
     def _ipsec_process_exists(self, conf, router, pid_files):
